@@ -1,13 +1,13 @@
 ;;; vertico-directory.el --- Ido-like directory navigation for Vertico -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2023 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.6
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4") (vertico "1.6"))
-;; Homepage: https://github.com/minad/vertico
+;; Version: 1.10
+;; Package-Requires: ((emacs "28.1") (compat "30") (vertico "1.10"))
+;; URL: https://github.com/minad/vertico
 
 ;; This file is part of GNU Emacs.
 
@@ -116,10 +116,5 @@ Exit with current input if prefix ARG is given."
                      (eq ?/ (char-before (- (point) 2)))))
         (delete-region (overlay-start ov) (overlay-end ov))))))
 
-;; Emacs 28: Do not show Vertico commands in M-X
-(dolist (sym '(vertico-directory-up vertico-directory-enter
-               vertico-directory-delete-char vertico-directory-delete-word))
-  (put sym 'completion-predicate #'vertico--command-p))
-
 (provide 'vertico-directory)
 ;;; vertico-directory.el ends here
