@@ -1,13 +1,13 @@
 ;;; vertico.el --- VERTical Interactive COmpletion -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2023 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.6
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
-;; Homepage: https://github.com/minad/vertico
+;; Version: 1.10
+;; Package-Requires: ((emacs "28.1") (compat "30"))
+;; URL: https://github.com/minad/vertico
 ;; Keywords: convenience, files, matching, completion
 
 ;; This file is part of GNU Emacs.
@@ -42,7 +42,8 @@
 (defgroup vertico nil
   "VERTical Interactive COmpletion."
   :link '(info-link :tag "Info Manual" "(vertico)")
-  :link '(url-link :tag "Homepage" "https://github.com/minad/vertico")
+  :link '(url-link :tag "Website" "https://github.com/minad/vertico")
+  :link '(url-link :tag "Wiki" "https://github.com/minad/vertico/wiki")
   :link '(emacs-library-link :tag "Library Source" "vertico.el")
   :group 'convenience
   :group 'minibuffer
@@ -66,9 +67,10 @@
 (defcustom vertico-preselect 'directory
   "Configure if the prompt or first candidate is preselected.
 - prompt: Always select the prompt.
-- first: Always select the first candidate.
+- first: Select the first candidate, allow prompt selection.
+- no-prompt: Like first, but forbid selection of the prompt entirely.
 - directory: Like first, but select the prompt if it is a directory."
-  :type '(choice (const prompt) (const first) (const directory)))
+  :type '(choice (const prompt) (const first) (const no-prompt) (const directory)))
 
 (defcustom vertico-scroll-margin 2
   "Number of lines at the top and bottom when scrolling.
@@ -249,38 +251,28 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
 
 (defun vertico--affixate (cands)
   "Annotate CANDS with annotation function."
-  (if-let ((aff (or (vertico--metadata-get 'affixation-function)
-                    (plist-get completion-extra-properties :affixation-function))))
+  (if-let ((aff (vertico--metadata-get 'affixation-function)))
       (funcall aff cands)
-    (if-let ((ann (or (vertico--metadata-get 'annotation-function)
-                      (plist-get completion-extra-properties :annotation-function))))
+    (if-let ((ann (vertico--metadata-get 'annotation-function)))
         (cl-loop for cand in cands collect
-                 (let ((suffix (or (funcall ann cand) "")))
+                 (let ((suff (or (funcall ann cand) "")))
                    ;; The default completion UI adds the `completions-annotations'
                    ;; face if no other faces are present.
-                   (unless (text-property-not-all 0 (length suffix) 'face nil suffix)
-                     (setq suffix (propertize suffix 'face 'completions-annotations)))
-                   (list cand "" suffix)))
+                   (unless (text-property-not-all 0 (length suff) 'face nil suff)
+                     (setq suff (propertize suff 'face 'completions-annotations)))
+                   (list cand "" suff)))
       (cl-loop for cand in cands collect (list cand "" "")))))
 
 (defun vertico--move-to-front (elem list)
   "Move ELEM to front of LIST."
-  (if-let ((found (member elem list)))
+  (if-let ((found (member elem list))) ;; No duplicates, compare with Corfu.
       (nconc (list (car found)) (delq (setcar found nil) list))
     list))
 
 (defun vertico--filter-completions (&rest args)
   "Compute all completions for ARGS with lazy highlighting."
-  (defvar completion-lazy-hilit)
-  (defvar completion-lazy-hilit-fn)
-  (cl-letf* ((completion-lazy-hilit t)
-             (completion-lazy-hilit-fn nil)
-             ((symbol-function #'completion-hilit-commonality)
-              (lambda (cands prefix &optional base)
-                (setq completion-lazy-hilit-fn
-                      (lambda (x) (car (completion-hilit-commonality (list x) prefix base))))
-                (and cands (nconc cands base)))))
-    (if (eval-when-compile (>= emacs-major-version 30))
+  (dlet ((completion-lazy-hilit t) (completion-lazy-hilit-fn nil))
+    (static-if (>= emacs-major-version 30)
         (cons (apply #'completion-all-completions args) completion-lazy-hilit-fn)
       (cl-letf* ((orig-pcm (symbol-function #'completion-pcm--hilit-commonality))
                  (orig-flex (symbol-function #'completion-flex-all-completions))
@@ -299,12 +291,17 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
                             (condition-case nil
                                 (car (completion-pcm--hilit-commonality pattern (list x)))
                               (t x))))
-                    cands)))
+                    cands))
+                 ((symbol-function #'completion-hilit-commonality)
+                  (lambda (cands prefix &optional base)
+                    (setq completion-lazy-hilit-fn
+                          (lambda (x) (car (completion-hilit-commonality (list x) prefix base))))
+                    (and cands (nconc cands base)))))
         (cons (apply #'completion-all-completions args) completion-lazy-hilit-fn)))))
 
 (defun vertico--metadata-get (prop)
   "Return PROP from completion metadata."
-  (completion-metadata-get vertico--metadata prop))
+  (compat-call completion-metadata-get vertico--metadata prop))
 
 (defun vertico--sort-function ()
   "Return the sorting function."
@@ -319,7 +316,7 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
                (before (substring content 0 pt))
                (after (substring content pt))
                ;; bug#47678: `completion-boundaries' fails for `partial-completion'
-               ;; if the cursor is moved between the slashes of "~//".
+               ;; if the cursor is moved before the slashes of "~//".
                ;; See also corfu.el which has the same issue.
                (bounds (condition-case nil
                            (completion-boundaries before table pred after)
@@ -355,9 +352,10 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
       (vertico--candidates . ,all)
       (vertico--total . ,(length all))
       (vertico--hilit . ,(or hl #'identity))
-      (vertico--allow-prompt . ,(or def-missing (eq vertico-preselect 'prompt)
-                                    (memq minibuffer--require-match
-                                          '(nil confirm confirm-after-completion))))
+      (vertico--allow-prompt . ,(and (not (eq vertico-preselect 'no-prompt))
+                                     (or def-missing (eq vertico-preselect 'prompt)
+                                         (memq minibuffer--require-match
+                                               '(nil confirm confirm-after-completion)))))
       (vertico--lock-candidate . ,lock)
       (vertico--groups . ,(cadr groups))
       (vertico--all-groups . ,(or (caddr groups) vertico--all-groups))
@@ -524,7 +522,8 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
     (vertico--update 'interruptible)
     (vertico--prompt-selection)
     (vertico--display-count)
-    (vertico--display-candidates (vertico--arrange-candidates))))
+    (vertico--display-candidates (vertico--arrange-candidates))
+    (vertico--resize)))
 
 (defun vertico--goto (index)
   "Go to candidate with INDEX."
@@ -552,8 +551,8 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
   (let ((rm minibuffer--require-match))
     (or (memq rm '(nil confirm-after-completion))
         (equal "" input) ;; Null completion, returns default value
-        (and (functionp rm) (funcall rm input)) ;; Emacs 29 supports functions
-        (test-completion input minibuffer-completion-table minibuffer-completion-predicate)
+        (if (functionp rm) (funcall rm input) ;; Emacs 29 supports functions
+          (test-completion input minibuffer-completion-table minibuffer-completion-predicate))
         (if (eq rm 'confirm) (eq (ignore-errors (read-char "Confirm")) 13)
           (minibuffer-message "Match required") nil))))
 
@@ -606,23 +605,19 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
   "Update candidates overlay `vertico--candidates-ov' with LINES."
   (move-overlay vertico--candidates-ov (point-max) (point-max))
   (overlay-put vertico--candidates-ov 'after-string
-               (apply #'concat #(" " 0 1 (cursor t)) (and lines "\n") lines))
-  (vertico--resize-window (length lines)))
+               (apply #'concat #(" " 0 1 (cursor t)) (and lines "\n") lines)))
 
-(cl-defgeneric vertico--resize-window (height)
-  "Resize active minibuffer window to HEIGHT."
+(cl-defgeneric vertico--resize ()
+  "Resize active minibuffer window."
   (setq-local truncate-lines (< (point) (* 0.8 (vertico--window-width)))
-              resize-mini-windows 'grow-only
+              resize-mini-windows vertico-resize
               max-mini-window-height 1.0)
   (unless truncate-lines (set-window-hscroll nil 0))
-  (unless (frame-root-window-p (active-minibuffer-window))
-    (unless vertico-resize (setq height (max height vertico-count)))
-    (let ((dp (- (max (cdr (window-text-pixel-size))
-                      (* (default-line-height) (1+ height)))
+  (unless (or vertico-resize (frame-root-window-p (active-minibuffer-window)))
+    (let ((delta (- (max (cdr (window-text-pixel-size))
+                         (* (default-line-height) (1+ vertico-count)))
                  (window-pixel-height))))
-      (when (or (and (> dp 0) (/= height 0))
-                (and (< dp 0) (eq vertico-resize t)))
-        (window-resize nil dp nil nil 'pixelwise)))))
+      (when (/= 0 delta) (window-resize nil delta nil nil 'pixelwise)))))
 
 (cl-defgeneric vertico--prepare ()
   "Ensure that the state is prepared before running the next command."
@@ -750,10 +745,14 @@ When the prefix argument is 0, the group order is reset."
   "Return non-nil if Vertico is active in BUFFER."
   (buffer-local-value 'vertico--input buffer))
 
-;; Emacs 28: Do not show Vertico commands in M-X
-(dolist (sym '(vertico-next vertico-next-group vertico-previous vertico-previous-group
-               vertico-scroll-down vertico-scroll-up vertico-exit vertico-insert
-               vertico-exit-input vertico-save vertico-first vertico-last))
+;; Do not show Vertico commands in M-X
+(dolist (sym '( vertico-next vertico-next-group vertico-previous vertico-previous-group
+                vertico-scroll-down vertico-scroll-up vertico-exit vertico-insert
+                vertico-exit-input vertico-save vertico-first vertico-last
+                vertico-repeat-previous ;; autoloads in vertico-repeat.el
+                vertico-quick-jump vertico-quick-exit vertico-quick-insert ;; autoloads in vertico-quick.el
+                vertico-directory-up vertico-directory-enter ;; autoloads in vertico-directory.el
+                vertico-directory-delete-char vertico-directory-delete-word))
   (put sym 'completion-predicate #'vertico--command-p))
 
 (provide 'vertico)
